@@ -95,7 +95,6 @@ log_score (const gchar * progname, const gchar * level, gchar * username,
    GList *scores = NULL, *anode;
    gchar *game_score_file;
    gfloat ascore;
-   time_t atime;
    struct ascore_t *anitem, *curscore;
    int i;
    gint retval = 1;
@@ -103,22 +102,23 @@ log_score (const gchar * progname, const gchar * level, gchar * username,
 
    game_score_file = gnome_get_score_file_name (progname, level);
 
-   infile = fopen (game_score_file, "rt");
+   infile = fopen (game_score_file, "r");
    if (infile)
      {
        while(fgets(buf, sizeof(buf), infile))
 	 {
+	     long ltime;
 	     i = strlen (buf) - 1;	/* Chomp */
 	     while (isspace (buf[i]))
 	       buf[i--] = '\0';
 
-	     if(sscanf(buf, "%f %ld %s", &ascore, &atime, name) != 3)
+	     if(sscanf(buf, "%f %ld %s", &ascore, &ltime, name) != 3)
 	       break;
 
 	     anitem = g_new(struct ascore_t, 1);
 	     anitem->score = ascore;
 	     anitem->username = g_strdup (name);
-	     anitem->scoretime = atime;
+	     anitem->scoretime = (time_t)ltime;
 	     scores = g_list_append (scores, (gpointer) anitem);
 	  }
 	fclose (infile);
@@ -162,7 +162,7 @@ log_score (const gchar * progname, const gchar * level, gchar * username,
    
    /* we dont create the file; it must already exist */
    truncate (game_score_file, 0);
-   outfile = fopen (game_score_file, "r+t");
+   outfile = fopen (game_score_file, "r+");
    
    if (outfile)
      {
@@ -380,7 +380,7 @@ gnome_score_get_notable (gchar * gamename,
    
    infile_name = gnome_get_score_file_name (realname, level);
    
-   infile = fopen (infile_name, "rt");
+   infile = fopen (infile_name, "r");
    g_free (infile_name);
    
    if (infile)
