@@ -308,7 +308,7 @@ translations_add(GtkWidget *button, GnomeDEntryEdit *dee)
 	
   /*we are setting the current language so set the easy page entries*/
   /*FIXME: do the opposite as well!, but that's not that crucial*/
-  language_list = gnome_i18n_get_language_list("LC_ALL");
+  language_list = gnome_i18n_get_language_list("LC_MESSAGES");
   curlang = language_list ? language_list->data : NULL;
   if ((curlang && strcmp(curlang,lang)==0) ||
       ((!curlang || strcmp(curlang,"C")==0) && !*lang)) {
@@ -566,6 +566,7 @@ gnome_dentry_edit_sync_display(GnomeDEntryEdit *dee,
 			       dentry->terminal);
   
   /*set the names and comments from our i18n list*/
+  gtk_clist_clear (GTK_CLIST(dee->translations));
   i18n_list = gnome_desktop_entry_get_i18n_list (dentry);
   for (li=i18n_list; li; li=li->next) {
     char *text[3];
