@@ -23,10 +23,8 @@
 #include <gdk_imlib.h>
 #include "gnome-canvas.h"
 #include "gnome-druid-page.h"
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+
+BEGIN_GNOME_DECLS
 
 #define GNOME_TYPE_DRUID_PAGE_STANDARD			(gnome_druid_page_standard_get_type ())
 #define GNOME_DRUID_PAGE_STANDARD(obj)			(GTK_CHECK_CAST ((obj), GNOME_TYPE_DRUID_PAGE_STANDARD, GnomeDruidPageStandard))
@@ -68,7 +66,7 @@ struct _GnomeDruidPageStandardClass
 
 GtkType    gnome_druid_page_standard_get_type      (void);
 GtkWidget *gnome_druid_page_standard_new           (void);
-GtkWidget *gnome_druid_page_standard_new_with_vals (gchar *title, GdkImlibImage *logo);
+GtkWidget *gnome_druid_page_standard_new_with_vals (const gchar *title, GdkImlibImage *logo);
 void gnome_druid_page_standard_set_bg_color        (GnomeDruidPageStandard *druid_page_standard,
 						    GdkColor *color);
 void gnome_druid_page_standard_set_logo_bg_color   (GnomeDruidPageStandard *druid_page_standard,
@@ -76,14 +74,11 @@ void gnome_druid_page_standard_set_logo_bg_color   (GnomeDruidPageStandard *drui
 void gnome_druid_page_standard_set_title_color     (GnomeDruidPageStandard *druid_page_standard,
 						    GdkColor *color);
 void gnome_druid_page_standard_set_title           (GnomeDruidPageStandard *druid_page_standard,
-						    gchar *title);
+						    const gchar *title);
 void gnome_druid_page_standard_set_logo            (GnomeDruidPageStandard *druid_page_standard,
 						    GdkImlibImage *logo_image);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+END_GNOME_DECLS
 
 #endif /* __GNOME_DRUID_PAGE_STANDARD_H__ */
 
