@@ -56,6 +56,18 @@ gnome_scores_init (GnomeScores *gs) {}
 static void
 gnome_scores_class_init (GnomeScoresClass *class) {}
 
+/**
+ * gnome_scores_new:
+ * @n_scores:
+ * @names:
+ * @scores:
+ * @times:
+ * @clear:
+ *
+ * Description:
+ *
+ * Returns: A new #GnomeScores widget
+ */
 GtkWidget * 
 gnome_scores_new (  guint n_scores, 
 		    gchar **names, 
@@ -145,6 +157,16 @@ gnome_scores_new (  guint n_scores,
 	return retval;
 }
 
+/**
+ * gnome_scores_set_color:
+ * @gs: A #GnomeScores widget
+ * @n:
+ * @col:
+ *
+ * Description:
+ *
+ * Returns:
+ */
 void
 gnome_scores_set_color(GnomeScores *gs, guint n, GdkColor *col)
 {
@@ -160,6 +182,15 @@ gnome_scores_set_color(GnomeScores *gs, guint n, GdkColor *col)
 	gtk_style_unref(s);
 }
 
+/**
+ * gnome_scores_set_def_color:
+ * @gs: A #GnomeScores widget
+ * @col:
+ *
+ * Description:
+ *
+ * Returns:
+ */
 void
 gnome_scores_set_def_color(GnomeScores *gs, GdkColor *col)
 {
@@ -170,6 +201,15 @@ gnome_scores_set_def_color(GnomeScores *gs, GdkColor *col)
 	}
 }
 
+/**
+ * gnome_scores_set_colors:
+ * @gs: A #GnomeScores widget
+ * @col:
+ *
+ * Description:
+ *
+ * Returns:
+ */
 void
 gnome_scores_set_colors(GnomeScores *gs, GdkColor *col)
 {
@@ -180,6 +220,15 @@ gnome_scores_set_colors(GnomeScores *gs, GdkColor *col)
 	}
 }
 
+/**
+ * gnome_scores_set_current_player:
+ * @gs: A #GnomeScores widget
+ * @i:
+ *
+ * Description:
+ *
+ * Returns:
+ */
 void
 gnome_scores_set_current_player (GnomeScores *gs, gint i)
 {
@@ -188,7 +237,17 @@ gnome_scores_set_current_player (GnomeScores *gs, gint i)
 	gtk_widget_set_name(GTK_WIDGET(gs->label_times[i]), "CurrentPlayer");
 }
 
-void gnome_scores_set_logo_label_title (GnomeScores *gs, gchar *txt)
+/**
+ * gnome_scores_set_logo_label_title:
+ * @gs: A #GnomeScores widget
+ * @txt:
+ *
+ * Description:
+ *
+ * Returns:
+ */
+void
+gnome_scores_set_logo_label_title (GnomeScores *gs, gchar *txt)
 {
 	if(gs->logo) {
 		g_print("Warning: gnome_scores_set_logo_* can be called only once\n");
@@ -202,8 +261,20 @@ void gnome_scores_set_logo_label_title (GnomeScores *gs, gchar *txt)
 }
 
 
-void gnome_scores_set_logo_label (GnomeScores *gs, gchar *txt, gchar *font,
-				  GdkColor *col)
+/**
+ * gnome_scores_set_logo_label:
+ * @gs: A #GnomeScores widget
+ * @txt:
+ * @font:
+ * @col:
+ *
+ * Description:
+ *
+ * Returns:
+ */
+void
+gnome_scores_set_logo_label (GnomeScores *gs, gchar *txt, gchar *font,
+			     GdkColor *col)
 {
 	GtkStyle *s = gtk_style_new(); /* i believe that i should copy the default style
 					  and change only the fg & font fields, how? */
@@ -233,7 +304,17 @@ void gnome_scores_set_logo_label (GnomeScores *gs, gchar *txt, gchar *font,
 	gtk_widget_show (gs->logo);
 }
 
-void gnome_scores_set_logo_widget (GnomeScores *gs, GtkWidget *w)
+/**
+ * gnome_scores_set_logo_widget:
+ * @gs: A #GnomeScores widget
+ * @w:
+ *
+ * Description:
+ *
+ * Returns:
+ */
+void
+gnome_scores_set_logo_widget (GnomeScores *gs, GtkWidget *w)
 {
 
 	if(gs->logo) {
@@ -245,7 +326,17 @@ void gnome_scores_set_logo_widget (GnomeScores *gs, GtkWidget *w)
 	gtk_box_pack_end (GTK_BOX(GNOME_DIALOG(gs)->vbox), gs->logo, TRUE, TRUE, 0);
 }
 
-void gnome_scores_set_logo_pixmap (GnomeScores *gs, gchar *pix_name)
+/**
+ * gnome_scores_set_logo_pixmap:
+ * @gs: A #GnomeScores widget
+ * @pix_name:
+ *
+ * Description:
+ *
+ * Returns:
+ */
+void
+gnome_scores_set_logo_pixmap (GnomeScores *gs, gchar *pix_name)
 {
 	GtkStyle *style;
 
@@ -263,6 +354,17 @@ void gnome_scores_set_logo_pixmap (GnomeScores *gs, gchar *pix_name)
 	gtk_widget_show (gs->logo);
 }
 
+/**
+ * gnome_scores_display:
+ * @gs: A #GnomeScores widget
+ * @app_name:
+ * @level:
+ * @pos:
+ *
+ * Description:
+ *
+ * Returns:
+ */
 void
 gnome_scores_display (gchar *title, gchar *app_name, gchar *level, int pos)
 {
