@@ -398,13 +398,6 @@ open_ptys (int utmp, int wtmp)
 #endif
 	  ;
 	term.c_cflag = 0
-#ifdef EXTB
-	  | EXTB
-#else
-# ifdef B9600
-	  | B9600
-# endif
-#endif /* EXTB */
 #ifdef CREAD
 	  | CREAD
 #endif
@@ -415,6 +408,21 @@ open_ptys (int utmp, int wtmp)
 	  | HUPCL
 #endif
 	  ;
+#ifdef EXTB
+	cfsetispeed (&term, EXTB);
+	cfsetospeed (&term, EXTB);
+#else
+#   ifdef B38400
+        cfsetispeed(&term, B38400);
+        cfsetospeed(&term, B38400);
+#   else
+#       ifdef B9600
+        cfsetispeed(&term, B9600);
+        cfsetospeed(&term, B9600);
+#       endif
+#   endif
+#endif /* EXTB */
+
 	term.c_lflag = 0
 #ifdef ECHO
 	  | ECHO
@@ -448,13 +456,17 @@ open_ptys (int utmp, int wtmp)
 	term.c_cc[VTIME] =  0;
 	term.c_cc[VMIN] = 0;
 	
-	/* Now set the characters. This is of course a religious matter
-	   but we use the defaults, with erase bound to the key gnome-terminal
-	   maps */
+	/*
+	 * Now set the characters. This is of course a religious matter
+	 * but we use the defaults, with erase bound to the key gnome-terminal
+	 * maps.
+	 *
+	 * These are the ones set by "stty sane".
+	 */
 	   
 	term.c_cc[VINTR] = 'C'-64;
 	term.c_cc[VQUIT] = '\\'-64;
-	term.c_cc[VERASE] = 'H'-64;
+	term.c_cc[VERASE] = 127;
 	term.c_cc[VKILL] =  'U'-64;
 	term.c_cc[VEOF] =  'D'-64;
 #ifdef VSWTC
@@ -560,8 +572,8 @@ sanity_checks (void)
 	 * Make sure stdin/stdout are open.  This is a requirement
 	 * for our program to work and closes potential security holes.
 	 */
-	if ((fcntl (0, F_GETFL, &flag) == EBADF) ||
-	    (fcntl (1, F_GETFL, &flag) == EBADF)){
+	if ((fcntl (0, F_GETFL, &flag) == -1 && errno == EBADF) ||
+	    (fcntl (1, F_GETFL, &flag) == -1 && errno == EBADF)){
 		exit (1);
 	}
 
@@ -572,7 +584,7 @@ sanity_checks (void)
 	 *
 	 * Make stderr point to a terminal.
 	 */
-	if (fcntl (2, F_GETFL, &flag) == EBADF){
+	if (fcntl (2, F_GETFL, &flag) == -1 && errno == EBADF){
 		stderr_fd = open ("/dev/tty", O_RDWR);
 		if (stderr_fd == -1){
 			stderr_fd = open ("/dev/null", O_RDWR);
