@@ -1371,7 +1371,7 @@ zvt_term_fix_scrollbar (ZvtTerm *term)
    or nothing
    returns true if a paste was actually requested. */
 static int
-request_paste (GtkWidget *widget, int type)
+request_paste (GtkWidget *widget, int type, gint32 time)
 {
   GdkAtom string_atom;
 #ifdef ZVT_UTF
@@ -1403,8 +1403,8 @@ request_paste (GtkWidget *widget, int type)
   }
 
   /* And request the "STRING" target for the primary selection */
-  gtk_selection_convert (widget, GDK_SELECTION_PRIMARY, string_atom,
-			 GDK_CURRENT_TIME);
+    gtk_selection_convert (widget, GDK_SELECTION_PRIMARY, string_atom,
+			   time);
   return 1;
 }
 
@@ -1514,7 +1514,7 @@ zvt_term_button_press (GtkWidget      *widget,
     break;
 
   case 2:			/* middle button - paste */
-    request_paste (widget, 0);
+    request_paste (widget, 0, event->time);
     break;
 
   case 3:			/* right button - select extend? */
@@ -1961,7 +1961,7 @@ zvt_term_selection_received (GtkWidget *widget, GtkSelectionData *selection_data
     struct _zvtprivate *zp = _ZVT_PRIVATE(widget);
 
     /* now, try again with next selection type */
-    if (request_paste(widget, zp->lastselectiontype+1)==0)
+    if (request_paste(widget, zp->lastselectiontype+1, time)==0)
       g_print ("Selection retrieval failed\n");
     return;
   }
@@ -2325,7 +2325,7 @@ zvt_term_key_press (GtkWidget *widget, GdkEventKey *event)
   case GDK_KP_Insert:
   case GDK_Insert:
     if ((event->state & GDK_SHIFT_MASK) == GDK_SHIFT_MASK){
-        request_paste (widget, 0);
+        request_paste (widget, 0, event->time);
     } else {
       p+=sprintf (p, "\033[2~");
     }
@@ -2517,8 +2517,8 @@ zvt_term_title_changed (ZvtTerm *term, VTTITLE_TYPE type, char *str)
  * @term: An initialised &ZvtTerm.
  * @regex: A regular expression to match.  It should be concise
  * enough so that it doesn't match whole lines.
- * @highlight_mask: Mask of bits used to highlight the text
- * as the mouse moves over it.
+ * @highlight_mask: Mask of bits used to set the attributes used
+ * to highlight the match as the mouse moves over it.
  * @data: User data.
  * 
  * Add a new auto-match regular expression.  The
@@ -2529,8 +2529,12 @@ zvt_term_title_changed (ZvtTerm *term, VTTITLE_TYPE type, char *str)
  * line in the visible buffer.
  *
  * The @highlight_mask is taken from the VTATTR_* bits, as defined
- * in vt.h.  These include VTATTR_BOLD, VTATTR_UNDERLINE, etc, but
- * not the colours.
+ * in vt.h.  These include VTATTR_BOLD, VTATTR_UNDERLINE, etc.
+ * Colours may also be set by including the colour index in the
+ * appropriate bit position.  Colours and attributes may be combined.
+ *
+ * e.g. to set foreground colour 2, and background colour 5, use
+ * highlight_mask = (2<<VTATTR_FORECOLOURB)|(5<<VTATTR_BACKCOLOURB).
  *
  * Return value: Returns -1 when the regular expression is invalid
  * and cannot be compiled (see regcomp(3c)).  Otherwise returns 0.
@@ -2546,8 +2550,7 @@ zvt_term_match_add(ZvtTerm *term, char *regex, uint32 highlight_mask, void *data
     m->regex = g_strdup(regex);
     vt_list_addtail(&vx->magic_list, (struct vt_listnode *)m);
     m->user_data = data;
-    m->highlight_mask = highlight_mask
-      & (VTATTR_MASK & ~(VTATTR_FORECOLOURM|VTATTR_BACKCOLOURM));
+    m->highlight_mask = highlight_mask & VTATTR_MASK;
   } else {
     g_free(m);
     return -1;
